//--------------------------------------------------------------
// File     : stm32_ub_id_check.c
// Datum    : 01.01.2015
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : keine
// Funktion : Auslesen der "unique ID" und "chip ID"
//--------------------------------------------------------------


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32_ub_id_check.h"




//--------------------------------------------------------------
// auslesen der "unique ID" der CPU (96bit)
// word_nr : UID_WORD_0 = Bit 0-31
//           UID_WORD_1 = Bit 32-63
//           UID_WORD_2 = Bit 64-95
//--------------------------------------------------------------
uint32_t UB_IDCHK_Read_UID(UID_WORD_t word_nr)
{
  uint32_t ret_wert=0;

  if(word_nr==UID_WORD_0) ret_wert=UID_WORD0_REG_ADR;
  if(word_nr==UID_WORD_1) ret_wert=UID_WORD1_REG_ADR;
  if(word_nr==UID_WORD_2) ret_wert=UID_WORD2_REG_ADR;

  return(ret_wert);
}


//--------------------------------------------------------------
// auslesen der "Device oder Revision ID" der CPU
// typ : [ID_DEVICE, ID_REVISION]
//  ID_DEVICE   : STM32F40x und STM32F41x = 0x0413
//                STM32F42x und STM32F43x = 0x0419
//  ID_REVISION : A = 0x1000
//                Z = 0x1001
//--------------------------------------------------------------
uint32_t UB_IDCHK_Read_ID(ID_TYP_t id_typ)
{
  uint32_t ret_wert=0;

  if(id_typ==ID_DEVICE) {
    ret_wert=(CPI_ID_REG_ADR&0x0FFF);
  }
  else if(id_typ==ID_REVISION) {
    ret_wert=(CPI_ID_REG_ADR&0xFFFF0000);
    ret_wert=ret_wert>>16;
  }

  return(ret_wert);
}

